@@ -6,7 +6,7 @@ require URI::WithBase;
 use strict;
 use vars qw(@EXPORT $VERSION);
 
-$VERSION = "5.00_01";
+$VERSION = "5.01";
 
 # Provide as much as possible of the old URI::URL interface for backwards
 # compatibility...
@@ -35,10 +35,19 @@ sub newlocal
     bless [URI::file->new_abs(shift)], $class;
 }
 
+{package URI::_foreign;
+    sub _init  # hope it is not defined
+    {
+	my $class = shift;
+	die "Unknown URI::URL scheme $_[1]:" if $URI::URL::STRICT;
+	$class->SUPER::_init(@_);
+    }
+}
+
 sub strict
 {
-    my $old = $URI::STRICT;
-    $URI::STRICT = shift if @_;
+    my $old = $URI::URL::STRICT;
+    $URI::URL::STRICT = shift if @_;
     $old;
 }
 
@@ -92,11 +101,6 @@ sub epath
     $path;
 }
 
-sub equery
-{
-    shift->SUPER::query(@_);
-}
-
 sub eparams
 {
     my $self = shift;
@@ -179,3 +183,121 @@ sub groupart { shift->_group(@_); }
 sub article  { shift->message(@_); }
 
 1;
+
+__END__
+
+=head1 NAME
+
+URI::URL - Uniform Resource Locators
+
+=head1 SYNOPSIS
+
+ $u1 = URI::URL->new($str, $base);
+ $u2 = $u1->abs;
+
+=head1 DESCRIPTION
+
+This module is provided for backwards compatibility with modules that
+depend on the interface provided by the C<URI::URL> class that used to
+be distributed with the libwww-perl library.
+
+The following differences compared to the C<URI> class interface exist:
+
+=over 3
+
+=item *
+
+The URI::URL module exports the url() function as an alternate
+constructor interface.
+
+=item *
+
+The constructor takes an optional $base argument.  See L<URI::WithBase>.
+
+=item *
+
+The URI::URL->newlocal class method is the same as URI::file->new_abs
+
+=item *
+
+URI::URL::strict(1)
+
+=item *
+
+$url->print_on method
+
+=item *
+
+$url->crack method
+
+=item *
+
+$url->full_path; same as ($uri->abs_path || "/")
+
+=item *
+
+$url->netloc; same as $uri->authority
+
+=item *
+
+$url->epath, $url->equery; same as $uri->path, $uri->query
+
+=item *
+
+$url->path and $url->query pass unescaped strings.
+
+=item *
+
+$url->path_components; same as $uri->path_segments (if you don't
+consider path segment parameters).
+
+=item *
+
+$url->params and $url->eparams methods.
+
+=item *
+
+$url->base method.  See L<URI::WithBase>.
+
+=item *
+
+$url->abs and $url->rel have an optional $base argument.  See
+L<URI::WithBase>.
+
+=item *
+
+$url->frag; same as $uri->fragment
+
+=item *
+
+$url->keywords; same as $uri->query_keywords;
+
+=item *
+
+$url->localpath with friends map to $uri->file
+
+=item *
+
+$url->address and $url->encoded822addr; same as $uri->to for mailto URI.
+
+=item *
+
+$url->groupart method for news URI.
+
+=item *
+
+$url->article; same as $uri->message
+
+=back
+
+
+
+=head1 SEE ALSO
+
+L<URI>, L<URI::WithBase>
+
+=head1 COPYRIGHT
+
+Copyright 1998 Gisle Aas.
+
+=cut
